Module modal

Module modal 

Modal cloud provider with image caching.

This provider integrates directly with Modal cloud sandboxes.

We persist a cache of Dockerfile hashes to the local disk to avoid rebuilding the Modal Sandbox Image.

Cache Keys

  • Dockerfile: dockerfile:{path} with hash validation

Structs

ModalProvider
Provider for Modal cloud sandboxes with image caching.
ModalSandbox
A Modal cloud sandbox instance.