Bundled scripts embedded in the binary, referenced via @filename.ext syntax.
Enums
- Bundled
Error - Errors that can occur during bundled script operations.
Functions
- expand_
command - Expands
@filename.extreferences in a command string to full cache paths.
Type Aliases
- Bundled
Result - Result type for bundled script operations.